use strict; use warnings;
BEGIN {
  unless(eval q{ use 5.008001; 1}) {
    print "Perl 5.008001 or better required\n";
    exit;
  }
}

# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.041.
use strict;
use warnings;

use Module::Build 0.3601;
use lib qw{inc}; use My::ModuleBuild;

my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.3601"
  },
  "configure_requires" => {
    "Module::Build" => "0.3601",
    "perl" => "5.008001"
  },
  "dist_abstract" => "Dist::Zilla plugin bundle used by Plicease",
  "dist_author" => [
    "Graham Ollis <plicease\@cpan.org>"
  ],
  "dist_name" => "Dist-Zilla-PluginBundle-Author-Plicease",
  "dist_version" => "1.90",
  "license" => "perl",
  "module_name" => "Dist::Zilla::PluginBundle::Author::Plicease",
  "recommends" => {
    "PerlX::Maybe::XS" => 0,
    "YAML::XS" => 0
  },
  "recursive_test_files" => 1,
  "requires" => {
    "Dist::Zilla" => "5.036",
    "Dist::Zilla::Plugin::AutoMetaResources" => "1.20",
    "Dist::Zilla::Plugin::CopyFilesFromBuild" => "0.150250",
    "Dist::Zilla::Plugin::InsertExample" => "0.04",
    "Dist::Zilla::Plugin::InstallGuide" => "1.200006",
    "Dist::Zilla::Plugin::MakeMaker" => 0,
    "Dist::Zilla::Plugin::MinimumPerl" => "1.006",
    "Dist::Zilla::Plugin::OurPkgVersion" => "0.06",
    "Dist::Zilla::Plugin::PodWeaver" => "4.006",
    "Dist::Zilla::Plugin::ReadmeAnyFromPod" => "0.150250",
    "Dist::Zilla::Plugin::Run::BeforeBuild" => "0.035",
    "File::chdir" => 0,
    "IPC::System::Simple" => "1.25",
    "JSON::PP" => 0,
    "Moose" => 0,
    "Path::Class" => "0.31",
    "PerlX::Maybe" => "0.003",
    "Pod::Markdown" => "1.400",
    "Test::Fixme" => "0.14",
    "Test::Pod" => "1.48",
    "Test::Pod::Coverage" => "1.10",
    "Test::Script" => "1.10",
    "Test::Version" => "2.00",
    "YAML" => "1.15",
    "autodie" => 0,
    "namespace::autoclean" => 0,
    "perl" => "5.008001"
  },
  "share_dir" => {
    "module" => {
      "Dist::Zilla::MintingProfile::Author::Plicease" => "profiles"
    }
  },
  "test_requires" => {
    "Capture::Tiny" => 0,
    "Dist::Zilla::App" => 0,
    "Test::Dir" => 0,
    "Test::File" => 0,
    "Test::File::ShareDir" => 0,
    "Test::More" => "0.94",
    "Test::Script" => "1.10",
    "perl" => "5.008001"
  }
);


my %fallback_build_requires = (
  "Capture::Tiny" => 0,
  "Dist::Zilla::App" => 0,
  "Module::Build" => "0.3601",
  "Test::Dir" => 0,
  "Test::File" => 0,
  "Test::File::ShareDir" => 0,
  "Test::More" => "0.94",
  "Test::Script" => "1.10",
  "perl" => "5.008001"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = My::ModuleBuild->new(%module_build_args);


$build->create_build_script;
