package Foo;

use strict;
use warnings;

# ABSTRACT: The Foo module
# VERSION

=head1 DESCRIPTION

this is the description.

=head1 AUTHOR

Blah balh

balh

=head1 COPYRIGHT AND LICENSE

Copyright (c) 2013 Graham THE Ollis

=cut

1;
